﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/route53-recovery-readiness/Route53RecoveryReadiness_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/route53-recovery-readiness/model/DNSTargetResource.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace Route53RecoveryReadiness
{
namespace Model
{

  /**
   * The resource element of a ResourceSet<p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/route53-recovery-readiness-2019-12-02/Resource">AWS
   * API Reference</a></p>
   */
  class AWS_ROUTE53RECOVERYREADINESS_API Resource
  {
  public:
    Resource();
    Resource(Aws::Utils::Json::JsonView jsonValue);
    Resource& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * The component id of the resource, generated by the service when
     * dnsTargetResource is used
     */
    inline const Aws::String& GetComponentId() const{ return m_componentId; }

    /**
     * The component id of the resource, generated by the service when
     * dnsTargetResource is used
     */
    inline bool ComponentIdHasBeenSet() const { return m_componentIdHasBeenSet; }

    /**
     * The component id of the resource, generated by the service when
     * dnsTargetResource is used
     */
    inline void SetComponentId(const Aws::String& value) { m_componentIdHasBeenSet = true; m_componentId = value; }

    /**
     * The component id of the resource, generated by the service when
     * dnsTargetResource is used
     */
    inline void SetComponentId(Aws::String&& value) { m_componentIdHasBeenSet = true; m_componentId = std::move(value); }

    /**
     * The component id of the resource, generated by the service when
     * dnsTargetResource is used
     */
    inline void SetComponentId(const char* value) { m_componentIdHasBeenSet = true; m_componentId.assign(value); }

    /**
     * The component id of the resource, generated by the service when
     * dnsTargetResource is used
     */
    inline Resource& WithComponentId(const Aws::String& value) { SetComponentId(value); return *this;}

    /**
     * The component id of the resource, generated by the service when
     * dnsTargetResource is used
     */
    inline Resource& WithComponentId(Aws::String&& value) { SetComponentId(std::move(value)); return *this;}

    /**
     * The component id of the resource, generated by the service when
     * dnsTargetResource is used
     */
    inline Resource& WithComponentId(const char* value) { SetComponentId(value); return *this;}


    
    inline const DNSTargetResource& GetDnsTargetResource() const{ return m_dnsTargetResource; }

    
    inline bool DnsTargetResourceHasBeenSet() const { return m_dnsTargetResourceHasBeenSet; }

    
    inline void SetDnsTargetResource(const DNSTargetResource& value) { m_dnsTargetResourceHasBeenSet = true; m_dnsTargetResource = value; }

    
    inline void SetDnsTargetResource(DNSTargetResource&& value) { m_dnsTargetResourceHasBeenSet = true; m_dnsTargetResource = std::move(value); }

    
    inline Resource& WithDnsTargetResource(const DNSTargetResource& value) { SetDnsTargetResource(value); return *this;}

    
    inline Resource& WithDnsTargetResource(DNSTargetResource&& value) { SetDnsTargetResource(std::move(value)); return *this;}


    /**
     * A list of RecoveryGroup ARNs and/or Cell ARNs that this resource is contained
     * within.
     */
    inline const Aws::Vector<Aws::String>& GetReadinessScopes() const{ return m_readinessScopes; }

    /**
     * A list of RecoveryGroup ARNs and/or Cell ARNs that this resource is contained
     * within.
     */
    inline bool ReadinessScopesHasBeenSet() const { return m_readinessScopesHasBeenSet; }

    /**
     * A list of RecoveryGroup ARNs and/or Cell ARNs that this resource is contained
     * within.
     */
    inline void SetReadinessScopes(const Aws::Vector<Aws::String>& value) { m_readinessScopesHasBeenSet = true; m_readinessScopes = value; }

    /**
     * A list of RecoveryGroup ARNs and/or Cell ARNs that this resource is contained
     * within.
     */
    inline void SetReadinessScopes(Aws::Vector<Aws::String>&& value) { m_readinessScopesHasBeenSet = true; m_readinessScopes = std::move(value); }

    /**
     * A list of RecoveryGroup ARNs and/or Cell ARNs that this resource is contained
     * within.
     */
    inline Resource& WithReadinessScopes(const Aws::Vector<Aws::String>& value) { SetReadinessScopes(value); return *this;}

    /**
     * A list of RecoveryGroup ARNs and/or Cell ARNs that this resource is contained
     * within.
     */
    inline Resource& WithReadinessScopes(Aws::Vector<Aws::String>&& value) { SetReadinessScopes(std::move(value)); return *this;}

    /**
     * A list of RecoveryGroup ARNs and/or Cell ARNs that this resource is contained
     * within.
     */
    inline Resource& AddReadinessScopes(const Aws::String& value) { m_readinessScopesHasBeenSet = true; m_readinessScopes.push_back(value); return *this; }

    /**
     * A list of RecoveryGroup ARNs and/or Cell ARNs that this resource is contained
     * within.
     */
    inline Resource& AddReadinessScopes(Aws::String&& value) { m_readinessScopesHasBeenSet = true; m_readinessScopes.push_back(std::move(value)); return *this; }

    /**
     * A list of RecoveryGroup ARNs and/or Cell ARNs that this resource is contained
     * within.
     */
    inline Resource& AddReadinessScopes(const char* value) { m_readinessScopesHasBeenSet = true; m_readinessScopes.push_back(value); return *this; }


    /**
     * The ARN of the AWS resource, can be skipped if dnsTargetResource is used
     */
    inline const Aws::String& GetResourceArn() const{ return m_resourceArn; }

    /**
     * The ARN of the AWS resource, can be skipped if dnsTargetResource is used
     */
    inline bool ResourceArnHasBeenSet() const { return m_resourceArnHasBeenSet; }

    /**
     * The ARN of the AWS resource, can be skipped if dnsTargetResource is used
     */
    inline void SetResourceArn(const Aws::String& value) { m_resourceArnHasBeenSet = true; m_resourceArn = value; }

    /**
     * The ARN of the AWS resource, can be skipped if dnsTargetResource is used
     */
    inline void SetResourceArn(Aws::String&& value) { m_resourceArnHasBeenSet = true; m_resourceArn = std::move(value); }

    /**
     * The ARN of the AWS resource, can be skipped if dnsTargetResource is used
     */
    inline void SetResourceArn(const char* value) { m_resourceArnHasBeenSet = true; m_resourceArn.assign(value); }

    /**
     * The ARN of the AWS resource, can be skipped if dnsTargetResource is used
     */
    inline Resource& WithResourceArn(const Aws::String& value) { SetResourceArn(value); return *this;}

    /**
     * The ARN of the AWS resource, can be skipped if dnsTargetResource is used
     */
    inline Resource& WithResourceArn(Aws::String&& value) { SetResourceArn(std::move(value)); return *this;}

    /**
     * The ARN of the AWS resource, can be skipped if dnsTargetResource is used
     */
    inline Resource& WithResourceArn(const char* value) { SetResourceArn(value); return *this;}

  private:

    Aws::String m_componentId;
    bool m_componentIdHasBeenSet;

    DNSTargetResource m_dnsTargetResource;
    bool m_dnsTargetResourceHasBeenSet;

    Aws::Vector<Aws::String> m_readinessScopes;
    bool m_readinessScopesHasBeenSet;

    Aws::String m_resourceArn;
    bool m_resourceArnHasBeenSet;
  };

} // namespace Model
} // namespace Route53RecoveryReadiness
} // namespace Aws
